==> material-code-0.4.0.tgz: package/esm/useEditorTheme/useEditorTheme.js <==
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import { EditorView } from '@codemirror/view';
import useTheme from '@mui/material/styles/useTheme';
export const useEditorTheme = (readOnly, dense, customVariant, customStyles) => {
  var _components$MuiTextFi, _components$MuiTextFi2, _components$MuiOutlin, _components$MuiOutlin2, _components$MuiOutlin3;

  const {
    palette,
    spacing,
    shape,
    components
  } = useTheme();
  const variant = customVariant || (components === null || components === void 0 ? void 0 : (_components$MuiTextFi = components.MuiTextField) === null || _components$MuiTextFi === void 0 ? void 0 : (_components$MuiTextFi2 = _components$MuiTextFi.defaultProps) === null || _components$MuiTextFi2 === void 0 ? void 0 : _components$MuiTextFi2.variant) || 'standard';
  const styleBorderRadius = components === null || components === void 0 ? void 0 : (_components$MuiOutlin = components.MuiOutlinedInput) === null || _components$MuiOutlin === void 0 ? void 0 : (_components$MuiOutlin2 = _components$MuiOutlin.styleOverrides) === null || _components$MuiOutlin2 === void 0 ? void 0 : (_components$MuiOutlin3 = _components$MuiOutlin2.root) === null || _components$MuiOutlin3 === void 0 ? void 0 : _components$MuiOutlin3.borderRadius;
  const borderRadiusTmp = typeof styleBorderRadius !== 'undefined' ? styleBorderRadius : shape.borderRadius;
  const borderRadius = variant === 'standard' ? typeof borderRadiusTmp === 'number' ? borderRadiusTmp + 'px' : borderRadiusTmp : 0;
  const styleMap = React.useMemo(() => ({
    textColor: (customStyles === null || customStyles === void 0 ? void 0 : customStyles.textColor) || palette.text.primary,
    headlineColor: (customStyles === null || customStyles === void 0 ? void 0 : customStyles.headlineColor) || (customStyles === null || customStyles === void 0 ? void 0 : customStyles.textColor) || palette.text.primary,
    backgroundColor: (customStyles === null || customStyles === void 0 ? void 0 : customStyles.backgroundColor) || palette.background.paper,
    lineHeight: dense ? (customStyles === null || customStyles === void 0 ? void 0 : customStyles.lineHeightDense) || '1.3em' : (customStyles === null || customStyles === void 0 ? void 0 : customStyles.lineHeight) || '1.42125em',
    linePadding: dense ? '0 2px 0 4px' : '1px 3px 1px 4px',
    contentPadding: dense ? 0 : spacing(0.5) + ' 0',
    borderDefault: palette.mode === 'light' ? 'rgba(0, 0, 0, 0.23)' : 'rgba(255, 255, 255, 0.23)',
    borderFocused: palette.primary.main,
    borderInvalid: palette.error.main,
    selectionMatch: (customStyles === null || customStyles === void 0 ? void 0 : customStyles.selectionMatch) || '#ae38a782',
    activeLineGutter: (customStyles === null || customStyles === void 0 ? void 0 : customStyles.activeLineGutter) || palette.divider,
    activeLine: (customStyles === null || customStyles === void 0 ? void 0 : customStyles.activeLine) || palette.divider,
    activeSelection: (customStyles === null || customStyles === void 0 ? void 0 : customStyles.activeSelection) || palette.divider
  }), [customStyles, dense, palette, spacing]);
  return React.useMemo(() => EditorView.theme(_objectSpread(_objectSpread(_objectSpread({
    '&': {
      color: styleMap.textColor,
      backgroundColor: styleMap.backgroundColor,
      width: '100%'
    },
    '&.cm-editor': {
      outline: '1px solid ' + (variant === 'standard' ? styleMap.borderDefault : 'transparent'),
      borderRadius: borderRadius
    }
  }, variant !== 'standard' || readOnly ? {} : {
    '&.cm-editor:hover': {
      outline: '1px solid ' + styleMap.textColor
    }
  }), variant === 'standard' ? {
    '&.cm-editor.invalid': {
      outline: '1px solid ' + styleMap.borderInvalid
    },
    '&.cm-editor.cm-focused': {
      outline: '2px solid ' + styleMap.borderFocused
    },
    '&.cm-editor.cm-focused.invalid': {
      outline: '2px solid ' + styleMap.borderInvalid
    }
  } : variant === 'embed' ? {
    '&.cm-editor.invalid': {
      outline: '1px solid ' + styleMap.borderInvalid
    },
    '&.cm-editor.cm-focused': {
      outline: 0
    },
    '&.cm-editor.cm-focused.invalid': {
      outline: '2px solid ' + styleMap.borderInvalid
    }
  } : {}), {}, {
    '& .cm-content': {
      caretColor: styleMap.textColor,
      padding: styleMap.contentPadding
    },
    '&.cm-focused .cm-cursor': {
      borderLeftColor: styleMap.textColor
    },
    '&.cm-editor .cm-line': {
      padding: styleMap.linePadding,
      lineHeight: styleMap.lineHeight
    },
    '&.cm-editor.cm-focused .cm-activeLine': {
      backgroundColor: styleMap.activeLine
    },
    '&.cm-editor .cm-activeLine': {
      backgroundColor: 'transparent'
    },
    '&.cm-editor .cm-selectionMatch': {
      backgroundColor: styleMap.selectionMatch
    },
    '&.cm-editor.cm-focused .cm-gutterElement.cm-activeLineGutter': {
      backgroundColor: styleMap.activeLineGutter
    },
    '& .cm-gutterElement.cm-activeLineGutter': {
      backgroundColor: 'transparent'
    },
    '&.cm-focused .cm-selectionBackground, ::selection': {
      backgroundColor: styleMap.activeSelection
    },
    '& .cm-gutters': {
      backgroundColor: palette.background.default,
      color: palette.text.secondary,
      border: 'none',
      borderTopLeftRadius: borderRadius,
      borderBottomLeftRadius: borderRadius
    },
    '& .cm-gutters .cm-lineNumbers .cm-gutterElement': {
      paddingLeft: spacing(1),
      lineHeight: styleMap.lineHeight
    }
  }), {
    dark: palette.mode === 'dark'
  }), [palette, spacing, readOnly, styleMap, borderRadius, variant]);
};

==> material-code-0.4.1.tgz: package/esm/useEditorTheme/useEditorTheme.js <==
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import { EditorView } from '@codemirror/view';
import useTheme from '@mui/material/styles/useTheme';
export const useEditorTheme = (readOnly, dense, customVariant, customStyles) => {
  var _components$MuiTextFi, _components$MuiTextFi2, _components$MuiOutlin, _components$MuiOutlin2, _components$MuiOutlin3;

  const {
    palette,
    spacing,
    shape,
    components
  } = useTheme();
  const variant = customVariant || (components === null || components === void 0 ? void 0 : (_components$MuiTextFi = components.MuiTextField) === null || _components$MuiTextFi === void 0 ? void 0 : (_components$MuiTextFi2 = _components$MuiTextFi.defaultProps) === null || _components$MuiTextFi2 === void 0 ? void 0 : _components$MuiTextFi2.variant) || 'standard';
  const styleBorderRadius = components === null || components === void 0 ? void 0 : (_components$MuiOutlin = components.MuiOutlinedInput) === null || _components$MuiOutlin === void 0 ? void 0 : (_components$MuiOutlin2 = _components$MuiOutlin.styleOverrides) === null || _components$MuiOutlin2 === void 0 ? void 0 : (_components$MuiOutlin3 = _components$MuiOutlin2.root) === null || _components$MuiOutlin3 === void 0 ? void 0 : _components$MuiOutlin3.borderRadius;
  const borderRadiusTmp = typeof styleBorderRadius !== 'undefined' ? styleBorderRadius : shape.borderRadius;
  const borderRadius = variant === 'standard' ? typeof borderRadiusTmp === 'number' ? borderRadiusTmp + 'px' : borderRadiusTmp : 0;
  const styleMap = React.useMemo(() => ({
    textColor: (customStyles === null || customStyles === void 0 ? void 0 : customStyles.textColor) || palette.text.primary,
    headlineColor: (customStyles === null || customStyles === void 0 ? void 0 : customStyles.headlineColor) || (customStyles === null || customStyles === void 0 ? void 0 : customStyles.textColor) || palette.text.primary,
    backgroundColor: (customStyles === null || customStyles === void 0 ? void 0 : customStyles.backgroundColor) || palette.background.paper,
    lineHeight: dense ? (customStyles === null || customStyles === void 0 ? void 0 : customStyles.lineHeightDense) || '1.3em' : (customStyles === null || customStyles === void 0 ? void 0 : customStyles.lineHeight) || '1.43125em',
    linePadding: dense ? '0 2px 0 4px' : '0px 3px 0px 4px',
    contentPadding: dense ? 0 : spacing(0.5) + ' 0',
    borderDefault: palette.mode === 'light' ? 'rgba(0, 0, 0, 0.23)' : 'rgba(255, 255, 255, 0.23)',
    borderFocused: palette.primary.main,
    borderInvalid: palette.error.main,
    selectionMatch: (customStyles === null || customStyles === void 0 ? void 0 : customStyles.selectionMatch) || '#ae38a782',
    activeLineGutter: (customStyles === null || customStyles === void 0 ? void 0 : customStyles.activeLineGutter) || palette.divider,
    activeLine: (customStyles === null || customStyles === void 0 ? void 0 : customStyles.activeLine) || palette.divider,
    activeSelection: (customStyles === null || customStyles === void 0 ? void 0 : customStyles.activeSelection) || (palette.mode === 'light' ? palette.info.light : palette.info.dark),
    width: (customStyles === null || customStyles === void 0 ? void 0 : customStyles.width) === null ? null : typeof (customStyles === null || customStyles === void 0 ? void 0 : customStyles.width) === 'undefined' ? '100%' : customStyles === null || customStyles === void 0 ? void 0 : customStyles.width
  }), [customStyles, dense, palette, spacing]);
  return React.useMemo(() => EditorView.theme(_objectSpread(_objectSpread(_objectSpread({
    '&': _objectSpread({
      color: styleMap.textColor,
      backgroundColor: styleMap.backgroundColor
    }, typeof styleMap.width === 'undefined' || styleMap.width === null ? {} : {
      width: styleMap.width
    }),
    '&.cm-editor': {
      outline: '1px solid ' + (variant === 'standard' ? styleMap.borderDefault : 'transparent'),
      borderRadius: borderRadius
    }
  }, variant !== 'standard' || readOnly ? {} : {
    '&.cm-editor:hover': {
      outline: '1px solid ' + styleMap.textColor
    }
  }), variant === 'standard' ? {
    '&.cm-editor.invalid': {
      outline: '1px solid ' + styleMap.borderInvalid
    },
    '&.cm-editor.cm-focused': {
      outline: '2px solid ' + styleMap.borderFocused
    },
    '&.cm-editor.cm-focused.invalid': {
      outline: '2px solid ' + styleMap.borderInvalid
    }
  } : variant === 'embed' ? {
    '&.cm-editor.invalid': {
      outline: '1px solid ' + styleMap.borderInvalid
    },
    '&.cm-editor.cm-focused': {
      outline: 0
    },
    '&.cm-editor.cm-focused.invalid': {
      outline: '2px solid ' + styleMap.borderInvalid
    }
  } : {}), {}, {
    '& .cm-content': {
      caretColor: styleMap.textColor,
      padding: styleMap.contentPadding,
      lineHeight: styleMap.lineHeight
    },
    '& .cm-scroller': {
      lineHeight: styleMap.lineHeight
    },
    '&.cm-focused .cm-cursor': {
      borderLeftColor: styleMap.textColor
    },
    '&.cm-editor .cm-line': {
      padding: styleMap.linePadding
    },
    '&.cm-editor.cm-focused .cm-activeLine': {
      backgroundColor: styleMap.activeLine
    },
    '&.cm-editor .cm-activeLine': {
      backgroundColor: 'transparent'
    },
    '&.cm-editor .cm-selectionMatch': {
      backgroundColor: styleMap.selectionMatch
    },
    '&.cm-editor.cm-focused .cm-gutterElement.cm-activeLineGutter': {
      backgroundColor: styleMap.activeLineGutter
    },
    '& .cm-gutterElement.cm-activeLineGutter': {
      backgroundColor: 'transparent'
    },
    '&.cm-focused .cm-selectionBackground, ::selection': {
      backgroundColor: styleMap.activeSelection
    },
    '& .cm-gutters': {
      backgroundColor: palette.background.default,
      color: palette.text.secondary,
      border: 'none',
      borderTopLeftRadius: borderRadius,
      borderBottomLeftRadius: borderRadius
    },
    '& .cm-gutters .cm-lineNumbers .cm-gutterElement': {
      paddingLeft: spacing(1)
    }
  }), {
    dark: palette.mode === 'dark'
  }), [palette, spacing, readOnly, styleMap, borderRadius, variant]);
};
